<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Systemmonitor</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Der Systemmonitor ist ein Werkzeug zur Überwachung der Systemauslastung in Echtzeit sowie zur Anzeige und Kontrolle von Prozessen und Diensten, die auf Ihrem System laufen.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Details ausblenden</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Gesamtnutzung</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Individuelle Nutzung</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lesen</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Schreiben</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 Sekunden</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 Tage %2 Stunden %3 Minuten</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Nutzung</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Aktuelle Frequenz</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Anbieter</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Sockel</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Logische Prozessoren</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualisierung</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i-Cache</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d-Cache</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2-Cache</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3-Cache</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Durchschnittliche Last</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Dateideskriptoren</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Threads</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Hostname</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>BS-Typ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Betriebszeit</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 Sekunden</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Keine Suchergebnisse</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>lade erneut</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inaktiv</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fehlgeschlagen</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>wird aktiviert</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>wird deaktiviert</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>nicht-gefunden</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>falsche-einstellung</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>vereint</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskiert</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>geladen</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/V</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>aktiviert</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>deaktiviert</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statisch</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>vorübergehend</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirekt</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>aktiviert-laufzeit</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskiert</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>generiert</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>tot</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-prä</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>läuft</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>beendet</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>neu laden</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fehlgeschlagen</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>automatischer-neustart</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Belegt</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Verfügbar</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Gemeinsam</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Zwischengespeichert</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Puffer</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Zwischengespeicherte Auslagerung</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Verändert</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Zugeordnet</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Auslagerung gesamt</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Freie Auslagerung</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modell</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Lesegeschwindigkeit</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Schreibgeschwindigkeit</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Kapazität</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Gelesene Sektoren</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Lesevorgänge/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Gelesene Sektoren/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Zusammengefasste Lesevorgänge/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Geschriebene Sektoren</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Abgeschlossene Schreibvorgänge </translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Zusammengefasste Schreibvorgänge</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Schreibvorgänge/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Geschriebene Sektoren/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Zusammengefasste Schreibvorgänge/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Beenden des Prozesses kann zu Datenverlust führen.
Sind Sie sicher, dass Sie fortfahren möchten?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Prozess beenden</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Erzwingtes Beenden des Prozesses kann zu Datenverlust führen.
Sind Sie sicher, dass Sie fortfahren möchten?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Das erzwungene Beenden dieser Anwendung kann zu Datenverlust führen.
Sind Sie sicher, dass Sie fortfahren wollen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Ende erzwingen</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Ende</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>IP-Adresse:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Netzmaske:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Präfixlänge:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Gültigkeitsbereich:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Verbindungsart</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Verbindungsqualität</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Signalstärke</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Rauschpegel</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Bandbreite</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX-Pakete</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX-Bytes</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX-Fehler</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX-Verworfen</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX-Überläufe</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX-Datenübertragungsblock</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX-Pakete</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX-Bytes</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX-Fehler</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX-Überläufe</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX-Trägerwelle</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX-Verworfen</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Kommandozeile</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Startzeit</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klicken Sie auf das Programm, das Sie beenden möchten</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Empfangen</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Datenträger lesen</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Datenträger schreiben</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Auslagerung</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Nicht aktiviert</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Insgesamt empfangen</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Insgesamt gesendet</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Datenträger</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Sehr hoch</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Niedrig</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Sehr niedrig</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Ungültig</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Fehler: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Prozesspriorität ändern ist fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Anwendungen</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Meine Prozesse</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Alle Prozesse</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Prozess pausieren ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Prozess fortsetzen ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Senden eines Signals an den Prozess fehlgeschlagen</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Prozess beenden ist fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 Programme und %2 Prozesse laufen)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Keine Antwort</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Anhalten</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Benachrichtigungsfeld</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Prozessort anzeigen</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschaften</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Prozess beenden</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Prozess fortsetzen</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Prozess abwürgen</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Priorität ändern</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Prozess anhalten</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Benutzerdefinierte Priorität</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Ändern</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Arbeitsspeicher</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Datenträger schreiben</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Datenträger lesen</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Benutzer</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorität</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Gemeinsamer Speicher</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Virtueller Speicher</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Nicht unterstützt</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Systemschutz</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Warnungen anzeigen, wenn die Auslastung die Schwellenwerte überschreitet</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>CPU-Warnschwellenwert (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Speicher-Warnschwellenwert (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Warnintervall (min)</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Fehler beim Festlegen des Dienststarttyps</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Fehler: Fehler beim Festlegen des Dienststarttyps aufgrund des abgestürzten Unterprozesses.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Name der Dienstinstanz</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Starttyp</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Last</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Starttyp</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Veränderbar)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Bereich: %1 - %2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Beenden des Programms erzwingen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Erweitern</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Kompakt</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Prozesse</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Dienste</translation>
    </message>
</context>
</TS>
